@@ -1,6 +1,6 @@
 # library file sourced by apt-zip-*
 
-APTZIPVERSION=0.13.2
+APTZIPVERSION=0.13.5
 export APTZIPVERSION
 
 CONFFILE=/etc/apt/apt-zip.conf
@@ -70,8 +70,8 @@ syntax_error()
 
 check_method()
 {
-    FILTER=${SHAREDIR}/methods/$METHOD
-    if [ ! -x $FILTER ]
+    FILTER="${SHAREDIR}/methods/$METHOD"
+    if [ ! -x "$FILTER" ]
     then
 	error "No $METHOD method installed."
     fi
@@ -79,7 +79,7 @@ check_method()
 
 check_medium()
 {
-    [ -d $MEDIUM ] || error "$MEDIUM does not exist (no mountpoint)"
+    [ -d "$MEDIUM" ] || error "$MEDIUM does not exist (no mountpoint)"
 }
 
 az_filter()
@@ -135,6 +135,11 @@ az_process_commandline ()
 	--medium|-m)
 	    if [ $# -lt 2 ]; then syntax_error "$1 needs an argument"; fi
 	    MEDIUM=$2
+	    #mount point might be relative ( . or .. are legal ;-)
+	    CWD=`pwd`
+	    cd "$MEDIUM"
+	    MEDIUM=`pwd`
+	    cd "${CWD}"	#if path is relative, it might contain spaces
 	    shift
 	    shift
 	    ;;
@@ -265,7 +270,7 @@ az_mount()
 	if [ "$MNTENTRY" ]
 	then
 	    WAS_MOUNTED=1
-	    if mount | grep "$MEDIUM.*[(,]ro[,)]" >/dev/null
+	    if mount | grep "${MEDIUM}.*[(,]ro[,)]" >/dev/null
 	    then
 		error "$MEDIUM is mounted READ ONLY"
 	    fi
@@ -294,7 +299,7 @@ az_umount()
 	if [ "$WAS_MOUNTED" = 0 ]
 	then
 	    echo "UnMounting $MEDIUM"
-	    umount $MEDIUM
+	    umount "$MEDIUM"
 	fi
     fi
 }
